
restible
########

**restible** is a python library that allows to selectively serialize different
kinds of python object into something that can be dumped to JSON or YAML.

.. readme_inclusion_marker

Installation
============

.. code-block:: shell

    $ pip install restible


Contributing
============

Setting up development repo
---------------------------

.. code-block:: shell

    $ git clone git@github.com:novopl/restible.git
    $ cd restible
    $ virtualenv env
    $ source ./env/bin/activate
    $ pip install -r requirements.txt -r devrequirements.txt
